@@ -1,6 +1,6 @@
 /*
 # MySQL Connector/Python - MySQL driver written in Python.
-# Copyright (c) 2014, 2015, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2014, 2016, Oracle and/or its affiliates. All rights reserved.
 
 # MySQL Connector/Python is licensed under the terms of the GPLv2
 # <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -269,12 +269,14 @@ fetch_fields(MYSQL_RES *result, unsigned int num_fields, MY_CHARSET_INFO *cs,
 void
 MySQL_dealloc(MySQL *self)
 {
-    MySQL_free_result(self);
-    if (&self->session)
-    {
-        mysql_close(&self->session);
-    }
-	Py_TYPE(self)->tp_free((PyObject*)self);
+    if (self) {
+        MySQL_free_result(self);
+        if (&self->session)
+        {
+            mysql_close(&self->session);
+        }
+        Py_TYPE(self)->tp_free((PyObject*)self);
+	}
 }
 
 /**
@@ -1023,14 +1025,16 @@ MySQL_commit(MySQL *self)
 PyObject*
 MySQL_connect(MySQL *self, PyObject *args, PyObject *kwds)
 {
-	char *host= NULL, *user= NULL, *password= NULL, *database= NULL,
-	     *unix_socket= NULL;
+	char *host= NULL, *user= NULL, *database= NULL, *unix_socket= NULL;
 	char *ssl_ca= NULL, *ssl_cert= NULL, *ssl_key= NULL;
-	PyObject *charset_name, *compress, *ssl_verify_cert;
+	PyObject *charset_name, *compress, *ssl_verify_cert, *password;
 	const char* auth_plugin;
 	unsigned long client_flags= 0;
 	unsigned int port= 3306, tmp_uint;
 	unsigned int protocol= 0;
+#if MYSQL_VERSION_ID >= 50711
+	unsigned int ssl_mode;
+#endif
 	my_bool abool;
 	MYSQL *res;
 
@@ -1043,7 +1047,11 @@ MySQL_connect(MySQL *self, PyObject *args, PyObject *kwds)
 		NULL
     };
 
-    if (!PyArg_ParseTupleAndKeywords(args, kwds, "|zzzzkzksssO!O!", kwlist,
+#ifdef PY3
+    if (!PyArg_ParseTupleAndKeywords(args, kwds, "|zzzzkzkzzzO!O!", kwlist,
+#else
+    if (!PyArg_ParseTupleAndKeywords(args, kwds, "|zzOzkzkzzzO!O!", kwlist,
+#endif
                                      &host, &user, &password, &database,
                                      &port, &unix_socket,
                                      &client_flags,
@@ -1104,13 +1112,50 @@ MySQL_connect(MySQL *self, PyObject *args, PyObject *kwds)
     mysql_options(&self->session, MYSQL_OPT_WRITE_TIMEOUT, (char*)&tmp_uint);
 
     if (ssl_ca || ssl_cert || ssl_key) {
-        abool= 1;
+#if MYSQL_VERSION_ID > 50703 && MYSQL_VERSION_ID < 50711
+        printf(">>>> %d\n", MYSQL_VERSION_ID);
+        {
+            abool= 1;
+            mysql_options(&self->session, MYSQL_OPT_SSL_ENFORCE, (char*)&abool);
+        }
+#endif
+#if MYSQL_VERSION_ID >= 50711
+        {
+            ssl_mode= SSL_MODE_REQUIRED;
+            mysql_options(&self->session, MYSQL_OPT_SSL_MODE, &ssl_mode);
+        }
+#endif
+
         if (ssl_verify_cert && ssl_verify_cert == Py_True)
         {
-            mysql_options(&self->session,
-                          MYSQL_OPT_SSL_VERIFY_SERVER_CERT, (char*)&abool);
+#if MYSQL_VERSION_ID >= 50711
+            {
+                ssl_mode= SSL_MODE_VERIFY_IDENTITY;
+                mysql_options(&self->session, MYSQL_OPT_SSL_MODE, &ssl_mode);
+            }
+#else
+            {
+                abool= 1;
+                mysql_options(&self->session,
+                              MYSQL_OPT_SSL_VERIFY_SERVER_CERT, (char*)&abool);
+            }
+#endif
         }
         mysql_ssl_set(&self->session, ssl_key, ssl_cert, ssl_ca, NULL, NULL);
+    } else {
+        // Make sure to not enforce SSL
+#if MYSQL_VERSION_ID > 50703 && MYSQL_VERSION_ID < 50711
+        {
+            abool= 0;
+            mysql_options(&self->session, MYSQL_OPT_SSL_ENFORCE, (char*)&abool);
+        }
+#endif
+#if MYSQL_VERSION_ID >= 50711
+        {
+            ssl_mode= SSL_MODE_DISABLED;
+            mysql_options(&self->session, MYSQL_OPT_SSL_MODE, &ssl_mode);
+        }
+#endif
     }
 
     if (PyString_Check(self->auth_plugin)) {
@@ -1134,9 +1179,29 @@ MySQL_connect(MySQL *self, PyObject *args, PyObject *kwds)
         client_flags= client_flags & ~CLIENT_CONNECT_WITH_DB;
     }
 
-    res= mysql_real_connect(&self->session,
-                            host, user, password, database,
-    						port, unix_socket, client_flags);
+    if (client_flags & CLIENT_LOCAL_FILES) {
+        abool= 1;
+        mysql_options(&self->session, MYSQL_OPT_LOCAL_INFILE, (unsigned int*)&abool);
+    }
+
+#ifdef PY3
+    res= mysql_real_connect(&self->session, host, user, password, database,
+                            port, unix_socket, client_flags);
+#else
+    char* c_password;
+    if (PyUnicode_Check(password))
+    {
+        PyObject* u_password= PyUnicode_AsUTF8String(password);
+        c_password= PyString_AsString(u_password);
+        Py_DECREF(u_password);
+    }
+    else
+    {
+        c_password= PyString_AsString(password);
+    }
+    res= mysql_real_connect(&self->session, host, user, c_password, database,
+                            port, unix_socket, client_flags);
+#endif
 
     Py_END_ALLOW_THREADS
 
